/*      DEFCONState

This class defines the state of a node within the C2 Simulation. It can be passed to
report a change in DEFCON, or as an update to a new terminal that is logging
onto the simulation.  It also used as the means for C2 Sim to track the state of each node,
if the node is synthetic.

Note that we assume that the initial DFCON is not in transition, and that the date achieved
is of minor interest.

*/

import java.util.Date;

public class DEFCONState  {

    Date    Achieved;
    Date    Declared;
    boolean reported;
    byte    DeclaredLevel;
    byte    AchievedLevel;


    public DEFCONState (byte level, Date LastChange)    {
        Achieved =  LastChange;
        Declared = LastChange;
        reported = true;
        DeclaredLevel = level;
        AchievedLevel = level;
    }

    public void DirectDEFCONChange (Date theChangedate, byte DirectedLevel)  {

        Declared = theChangedate;
        reported = false;
        DeclaredLevel = DirectedLevel;
    }

    public void ReportDEFCONChange (Date theReportdate, byte level)  {
        Achieved =  theReportdate;
        reported = false;
        AchievedLevel = level;
    }

    public byte getAchievedLevel ()    {
        return AchievedLevel;
    }

   public byte getDeclaredLevel ()    {
        return DeclaredLevel;
   }

   public boolean hasItBeenReported ()    {
        return reported;
   }

   public Date getDateAchieved()    {
        return Achieved;
   }

   public Date getDateDeclared ()    {
        return Declared ;
   }

   public DEFCONState GetDEFCONCopy ()  {
        DEFCONState temp;
        temp = new DEFCONState (DeclaredLevel, Achieved);
        temp.Declared = Declared;
        temp.reported = reported;
        temp.AchievedLevel = AchievedLevel;
        return temp;
   }

}